@@ -4,10 +4,12 @@ decoupage: a view with webob
 
 import os
 
+from contenttransformer.app import FileTypeTransformer
 from formatters import formatters
 
 from genshi.builder import Markup
 from genshi.template import TemplateLoader
+from genshi.template.base import TemplateError
 from martini.config import ConfigMunger
 from paste.fileapp import FileApp
 from pkg_resources import resource_filename
@@ -59,6 +61,8 @@ class Decoupage(object):
         self.loader = TemplateLoader(self.template_directories, 
                                      auto_reload=self.auto_reload)
 
+        
+
     ### methods dealing with HTTP
     def __call__(self, environ, start_response):
         request = Request(environ)
@@ -73,15 +77,18 @@ class Decoupage(object):
                 res = self.get(request)
                 return res(environ, start_response)
             else:
-                fileserver = self.fileserver(path)
+                conf = self.conf(request.path_info.rsplit('/',1)[0])
+                if '/transformer' in conf:
+                    args = [i.split('=', 1) for i in conf['/transformer'].split(',') if '=' in i]
+                    fileserver = FileTypeTransformer(*args)
+                else:
+                    fileserver = FileApp
+                    
+                fileserver = fileserver(path)
                 return fileserver(environ, start_response)
         else:
             raise exc.HTTPNotFound()
 
-    def get_response(self, text, content_type='text/html'):
-        """construct a response to a GET request"""
-        res = Response(content_type=content_type, body=text)
-        return res
 
     def get(self, request):
         """
@@ -122,9 +129,11 @@ class Decoupage(object):
 
         # render the template
         template = conf.get('/template')
+        local_index = False 
         if template is None:
             if 'index.html' in [ f['name'] for f in files ]:
-                template = os.path.join(directory, 'index.html')
+                local_index = os.path.join(directory, 'index.html')
+                template = local_index
             else:
                 template = self.template
         else:
@@ -139,9 +148,16 @@ class Decoupage(object):
                     else:
                         raise IOError("template %s not found" % template)
                 
-        template = self.loader.load(template)
-        res = template.generate(**data).render('html', doctype='html')
-        return self.get_response(res)
+        try:
+            template = self.loader.load(template)
+            res = template.generate(**data).render('html', doctype='html')
+        except TemplateError:
+            if local_index:
+                return self.fileserver(local_index)
+            raise
+
+        return Response(content_type='text/html', body=res)
+
 
     ### internal methods
 
@@ -191,7 +207,7 @@ class Decoupage(object):
             parent_configuration = self.conf(inherit_directory)
             for key, value in parent_configuration.items():
                 if key.startswith('/') and key not in conf:
-                    conf[key] = value
+                    conf[key] = value                
 
         # cache configuration
         if not self.auto_reload:
